@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2017-02-03'; # DATE
-our $VERSION = '0.82'; # VERSION
+our $DATE = '2017-02-24'; # DATE
+our $VERSION = '0.83'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -201,8 +201,16 @@ sub after_gen_doc {
             }
         } else {
             if (defined $resdump) {
-                $resdump =~ s/^/ /gm;
-                push @result_lines, "Result:\n\n$resdump", "";
+                my @resdump = split /^/, $resdump;
+                if (my $max_lines = $eg->{'x.doc.max_result_lines'}) {
+                    $max_lines += 7; # to accomodate extra lines associated with envelopes and array enclosures
+                    if (@resdump > $max_lines) {
+                        my $n = int($max_lines/2);
+                        splice @resdump, $n, (@resdump - $max_lines + 1), "# ...snipped for brevity...\n";
+                        $resdump = join("", @resdump);
+                    }
+                }
+                push @result_lines, "Result:", "", (map {" $_"} @resdump), "";
             }
         }
         my @summary_lines;
@@ -416,7 +424,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.82 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2017-02-03.
+This document describes version 0.83 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2017-02-24.
 
 =head1 SYNOPSIS
 
@@ -454,7 +462,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
